@@ -10,11 +10,13 @@ package yara
 #include <yara.h>
 
 // rule_identifier is a union accessor function.
+// (CGO does not represent them properly to Go code.)
 static const char* rule_identifier(YR_RULE* r) {
 	return r->identifier;
 }
 
 // rule_namespace is a union accessor function.
+// (CGO does not represent them properly to Go code.)
 static const char* rule_namespace(YR_RULE* r) {
 	return r->ns->name;
 }
@@ -47,9 +49,8 @@ static void rule_metas(YR_RULE* r, const YR_META *metas[], int *n) {
 	return;
 }
 
-// meta_get is an accessor function for unions that are not directly
-// accessible from Go because CGO does not understand the union types
-// generated using the DECLARE_REFERENCE macro.
+// meta_get is a union accessor function.
+// (CGO does not represent them properly to Go code.)
 static void meta_get(YR_META *m, const char** identifier, char** string) {
 	*identifier = m->identifier;
 	*string = (char*)m->string;
@@ -71,6 +72,7 @@ static void rule_strings(YR_RULE* r, const YR_STRING *strings[], int *n) {
 }
 
 // string_identifier is a union accessor function.
+// (CGO does not represent them properly to Go code.)
 static const char* string_identifier(YR_STRING* s) {
 	return s->identifier;
 }
@@ -89,6 +91,20 @@ static void string_matches(YR_SCAN_CONTEXT *ctx, YR_STRING* s, const YR_MATCH *m
 	return;
 }
 
+// get_rules returns pointers to the RULE objects for a ruleset, using
+// YARA's macro-based implementation.
+static void get_rules(YR_RULES *ruleset, const YR_RULE *rules[], int *n) {
+	const YR_RULE *rule;
+	int i = 0;
+	yr_rules_foreach(ruleset, rule) {
+		if (i < *n)
+			rules[i] = rule;
+		i++;
+	}
+	*n = i;
+	return;
+}
+
 */
 import "C"
 import "unsafe"
@@ -258,3 +274,19 @@ func (r *Rule) Enable() {
 func (r *Rule) Disable() {
 	C.yr_rule_disable(r.cptr)
 }
+
+// GetRules returns a slice of rule objects that are part of the
+// ruleset.
+func (r *Rules) GetRules() (rules []Rule) {
+	var size C.int
+	C.get_rules(r.cptr, nil, &size)
+	if size == 0 {
+		return
+	}
+	ptrs := make([]*C.YR_RULE, int(size))
+	C.get_rules(r.cptr, &ptrs[0], &size)
+	for _, ptr := range ptrs {
+		rules = append(rules, Rule{ptr})
+	}
+	return
+}
